@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-from soundcard.rat import Rat
+from rat import Rat
 import const
 import gtk
 import mpdutils
