@@ -26,11 +26,29 @@ def play_wav(filename):
 
 soundcard.initialise_external_midiplayer(....)
 soundard.play_wav_file = play_wav
+----
+
+Api used to export exercises to midi file
+=========================================
+soundcard.start_export(export_to_filename)
+    Change soundcard.synth to point to another object that collects
+    the music send to it.
+soundcard.end_export()
+    Write the music collected since start_export to the file named when
+    start_export was called.
+    Then set soundcard.synth back to what is was earlier.
+
 """
 import sys
 from mpd.track import Track, PercussionTrack
 from soundcardexceptions import SoundInitException
+from exporter import MidiExporter
 synth = None
+midiexporter = None
+
+# _saved_synth is used to store the object pointed to by synth when
+# we are exporting using midiexporter.
+_saved_synth = None
 
 def win32_play_wav_file(filename):
     winsound.PlaySound(filename, winsound.SND_FILENAME | winsound.SND_ASYNC)
@@ -96,6 +114,22 @@ def play_perc(notelen, pitch, vel):
     m.note(notelen, pitch, vel)
     synth.play_track(m)
 
+def start_export(filename):
+    global midiexporter, _saved_synth, synth
+    if not midiexporter:
+        midiexporter = MidiExporter()
+    assert _saved_synth is None
+    _saved_synth = synth
+    synth = midiexporter
+    midiexporter.start_export(filename)
+
+def end_export():
+    global midiexporter, _saved_synth, synth
+    midiexporter.end_export()
+    assert _saved_synth is not None
+    synth = _saved_synth
+    _saved_synth = None
+
 instrument_sections = (
     'piano',
     'cromatic percussion',
