@@ -363,14 +363,14 @@ It is also possible that the OS sound setup is incorrect.
                     table.append_row("%i" % track_idx,
                                      p.get_question()['name'],
                                      s)
-                    soundcard.synth.start_export(os.path.join(
+                    soundcard.start_export(os.path.join(
                             export_dir, "track-%i.mid" % track_idx))
                     for n in range(lesson_info.get('repeat', 1)):
                         p.play_question()
                         if n != lesson_info.get('repeat', 1) - 1:
                             if 'delay' in lesson_info:
                                 delay(lesson_info['delay'], p.get_tempo())
-                    soundcard.synth.end_export()
+                    soundcard.end_export()
                 elif module in ('melodicinterval', 'harmonicinterval'):
                     t = self.m_teachers[module]
                     t.set_lessonfile(self.lessonfile_manager.get(lesson_id, 'filename'))
@@ -381,7 +381,7 @@ It is also possible that the OS sound setup is incorrect.
                         table.append_row("%i" % track_idx, "%s" % utils.int_to_intervalname(t.m_interval))
                     except AttributeError:
                         table.append_row("%i" % track_idx, "%s" % (" + ".join([utils.int_to_intervalname(q, False, True) for q in t.m_question])))
-                    soundcard.synth.start_export(os.path.join(
+                    soundcard.start_export(os.path.join(
                             export_dir, "track-%i.mid" % track_idx))
                     for n in range(lesson_info.get('repeat', 1)):
                         t.play_question()
@@ -389,7 +389,7 @@ It is also possible that the OS sound setup is incorrect.
                             if 'delay' in lesson_info:
                                 delay(lesson_info['delay'],
                                     (self.get_int('config/default_bpm'), 4))
-                    soundcard.synth.end_export()
+                    soundcard.end_export()
                 else:
                     print "ignoring exercise with module='%s'" % module
 #####
