@@ -126,12 +126,11 @@ class Gui(abstract.LessonbasedGui):
                 self.m_t.play_question()
                 self.g_entry.grab_focus()
         except mpd.MpdException, e:
-            exception_cleanup()
-            self.g_win.display_question_music_error_message(
-               self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+            if not self.standard_exception_handler(e, __file__, exception_cleanup):
+                raise
         except lessonfile.LessonfileException, e:
-            exception_cleanup()
-            self.g_win.display_exception_message(e, __file__)
+            if not self.standard_exception_handler(e, __file__, exception_cleanup):
+                raise
     def give_up(self, widget=None):
         self.m_t.give_up()
         self.g_new.set_sensitive(True)
