@@ -26,7 +26,6 @@ if __name__ == '__main__':
 debug_flag = ()
 
 import copy
-import unittest
 import gobject
 import sys
 import gtk, pango
@@ -65,12 +64,24 @@ class _HtmlWidgetCommon(object):
         pass
     def read_file_abs(self, filename):
         self.m_document_wd = os.path.dirname(filename)
-        self.source(file(filename, 'r').read())
+        self.source(self.read_and_encode_file(filename))
     def read_file_rel(self, filename):
         assert self.m_document_wd
         fn = os.path.join(self.m_document_wd, filename)
         self.m_document_wd = os.path.dirname(fn)
-        self.source(file(fn, 'r').read())
+        self.source(self.read_and_encode_file(fn))
+    def read_and_encode_file(self, filename):
+        """
+        Load the file named and make an unicode string of it.
+        """
+        s = open(filename, 'r').read()
+        r = re.compile('<meta.*?\scontent="(?P<content>.*?charset=(?P<charset>.*?)")')
+        m = r.search(s)
+        if (not m) or (not m.group('charset')):
+            charset = 'ascii'
+        else:
+            charset = m.group('charset')
+        return s.decode(charset, 'replace')
 
 
 class GtkHtml2Widget(gtk.ScrolledWindow, _HtmlWidgetCommon):
@@ -307,6 +318,15 @@ class ElementBaseClass(tree.TreeNode):
         for c in self.m_children:
             print "EE", c
             c.do_children()
+    def get_as_string(self, level=0):
+        """
+        Return a string representation of the tree. This function is
+        only used for module testing of the html parser.
+        """
+        s = "\n" + " " * level + "%s-%s-%s" % (self.m_name, self.m_first, self.m_last)
+        for n in self.m_children:
+            s += n.get_as_string(level + 1)
+        return s
 
 class Text(ElementBaseClass):
     def __init__(self, txt, pre=False):
@@ -736,120 +756,6 @@ class NewHTMLParser(HTMLParser):
                 head = c.pop()
                 return head
 
-class TestHtmlParser(unittest.TestCase):
-    def setUp(self):
-        self.m_parser = NewHTMLParser()
-    def test_simple(self):
-        self.m_parser.feed("<html><p>test</p></html>")
-        self.m_parser.calc_bounds()
-        x = self.m_parser.m_tree.get_as_string()
-        self.assertEquals(x, """
-html-None-None
- p-0-3
-  ::Text::-0-3""")
-    def test_links(self):
-        self.m_parser.feed("""
-<html>
-<body>
-<p>hei
-<a href="h.html">h.html</a>end</p>
-</body>
-</html>
-        """)
-        self.m_parser.calc_bounds()
-        x = self.m_parser.m_tree.get_as_string()
-        self.assertEquals(x, """
-html-None-None
- body-0-12
-  p-0-12
-   ::Text::-0-3
-   a-4-9
-    ::Text::-4-9
-   ::Text::-10-12""")
-    def test_img(self):
-        self.m_parser.feed("<html><p><img src='png/mainwin.png'/></p></html>")
-        self.m_parser.calc_bounds()#FIXME not complete
-        #x = self.m_parser.m_tree.get_as_string()
-        #print "'%s'" % x
-    def test_trademark(self):
-        self.m_parser.feed("""
-<html>
-<head>
-<title>TITTEL</title>
-</head>
-<body>
-<p>123<trademark class="copyright"/>456</p>
-</body>
-</html>""")
-        self.m_parser.calc_bounds()
-    def test_title(self):
-        self.m_parser.feed("<html><head><title>tittel</title></head><body><p>123</p></body></html>")
-        self.m_parser.calc_bounds()
-    def test_ignore_style(self):
-        self.m_parser.feed("<html><head><style>bla bla</style><title>test_ignore_style</title></head><body><p>123</p></body></html>")
-        self.m_parser.calc_bounds()
-    def test_linkrel_trouble(self):
-        self.m_parser.feed("""<html>
-<head>
-<link rel="next" href="solfege-intro.html" title="chapter1.introduction."></head><body><span class="application">gnu solfege</span> manual v3.0.0
-</body></html>""")
-        debug_flag = ()
-    def test_linkrel(self):
-        self.m_parser.feed("""<html>
-<head>
-<link rel="next" href="solfege-intro.html" title="chaption.">
-<link rel="next" href="solfege-intro.html" title="chaption.">
-</head>
-<body>test
-</body></html>""")
-        c = tree.Cursor(self.m_parser.m_tree)
-        self.assertEqual(c.get().m_name, 'html')
-        self.assertEqual(c.get().m_children[0].m_name, 'head')
-        c.go_next()
-        self.assertEqual(c.get().m_children[0].m_name, 'link')
-        self.assertEqual(c.get().m_children[1].m_name, 'link')
-        c.go_next_sibling()
-        self.assertEqual(c.get().m_name, 'body')
-        c.go_next()
-        self.assertEqual(c.get().m_name, 'p')
-        c.go_next()
-        self.assertEqual(c.get().m_name, '::Text::')
-    def test_table(self):
-        global debug_flag
-        #debug_flag = ('start', 'end')
-        self.m_parser.feed("""<html>
-<table border="1">
-<tr>
-  <td>C1</td>
-  <td>C2</td>
-</tr>
-<tr><td>D1</td></tr>
-</table>
-<p>end</p>
-</html>""")
-        self.m_parser.pop_head_out_of_tree()
-        self.m_parser.strip_whitespace()
-        self.m_parser.insert_newline_before_blocks()
-        self.m_parser.do_list_items()
-        self.m_parser.do_table()
-        #self.m_parser.calc_bounds()
-        #self.m_parser.m_tree.show()
-        debug_flag = ()
-    def test_table_colgroup(self):
-        self.m_parser.feed("""<html><body><table><colgroup><col><col></colgroup><tbody><tr><td>cell</td></tr></tbody></table></body></html>""")
-    def test_parse_all_user_manual(self):
-        import glob
-        for n in glob.glob("help/*/*.html"):
-            try:
-                p = NewHTMLParser()
-                p.feed(file(n, 'r').read())
-                p.pop_head_out_of_tree()
-               # p.post_process(p)
-            except Exception, e:
-                print "Failed:", n
-                raise e
-
-
 
 
 def _test():
@@ -879,7 +785,7 @@ def _test():
             self.show_all()
             self.connect('destroy', gtk.main_quit)
         def on_reload(self, btn):
-            s = file(self.m_filename, 'r').read()
+            s = open(self.m_filename, 'rU').read()
             self.g_html1.source(s)
             self.g_html2.source(s)
         def activate_cb(self, url):
@@ -899,10 +805,6 @@ else:
 
 if __name__ == '__main__':
     gtk.rc_parse("solfege.gtkrc")
-    if len(sys.argv) == 1:
-        unittest.main()
-    else:
-        #debug_flag = ('start', 'end')
-        _test()
+    _test()
 
 
