@@ -1147,7 +1147,7 @@ class Window(gtk.Window):
             do_del = True
             if self.m_tree.get_use_count(del_id) == 1:
                 if self.m_tree.get_dep_use_count(del_id) > 0:
-                    do_del = gu.dialog_yesno(_("Lessons depend on this lesson. Delete anyway, and update the dependency list for lessons that depend on this lesson?"), self)
+                    do_del = gu.dialog_yesno(_("Some lessons depend on this lesson. Delete anyway, and update the dependency list for lessons that depend on this lesson?"), self)
                     if do_del:
                         self.m_tree.remove_all_deps_of(del_id)
             if do_del:
