@@ -32,12 +32,12 @@ import htmlwidget
 import stock
 
 gtk.stock_add([('solfege-notehead', _("Add noteheads"), 0, 0, ''),
-               ('solfege-sharp', _("Add sharp"), 0, 0, ''),
-               ('solfege-double-sharp', _("Add double-sharp"), 0, 0, ''),
+               ('solfege-sharp', _("Add sharps"), 0, 0, ''),
+               ('solfege-double-sharp', _("Add double-sharps"), 0, 0, ''),
                ('solfege-natural', _("Remove accidentals"), 0, 0, ''),
-               ('solfege-flat', _("Add flat"), 0, 0, ''),
-               ('solfege-double-flat', _("Add double-flat"), 0, 0, ''),
-               ('solfege-erase', _("Delete tone"), 0, 0, ''),
+               ('solfege-flat', _("Add flats"), 0, 0, ''),
+               ('solfege-double-flat', _("Add double-flats"), 0, 0, ''),
+               ('solfege-erase', _("Delete tones"), 0, 0, ''),
                ])
 app_version = "0.1.4"
 
@@ -106,7 +106,7 @@ lessonfile_actions = [
     ('DoubleFlatCursor', 'solfege-double-flat', None, None,
      _('Add double-flats'), 'select_cursor_2flat_cb'),
     ('EraseCursor', 'solfege-erase', None, None,
-     _('Erase tones'), 'select_cursor_erase_cb'),
+     _('Delete tones'), 'select_cursor_erase_cb'),
 ]
 ui_string = """<ui>
   <menubar name='Menubar'>
