@@ -15,19 +15,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-if __name__ == '__main__':
-    import sys
-    import pygtk
-    pygtk.require("2.0")
-    import sys
-    sys.path.append(".")
-    sys.path.append("src")
-    import i18n
-    i18n.setup(".")
-
-import gtk, gobject
-import mpd, gu, cfg
+import gtk
 import gobject
+import mpd
+import cfg
 
 DELAY1 = 500
 DELAY2 = 50
@@ -133,12 +124,12 @@ class NotenameRangeController(object):
         self.g_spin_high.connect('value-changed', self.on_high_changed)
         self.m_lowest_value = mpd.notename_to_int(lowest_value)
         self.m_highest_value = mpd.notename_to_int(highest_value)
-    def on_low_changed(self, widget, *v):
+    def on_low_changed(self, widget, v):
         if widget.get_value() > self.g_spin_high.get_value():
             self.g_spin_low.set_value(self.g_spin_high.get_value())
         elif widget.get_value() < self.m_lowest_value:
             self.g_spin_low.set_value(self.m_lowest_value)
-    def on_high_changed(self, widget, *v):
+    def on_high_changed(self, widget, v):
         if widget.get_value() < self.g_spin_low.get_value():
             self.g_spin_high.set_value(self.g_spin_low.get_value())
         elif widget.get_value() > self.m_highest_value:
@@ -179,33 +170,3 @@ class nNotenameRangeController(NotenameRangeController, cfg.ConfigUtils):
             self.set_string(self.m_name_high, highest_value)
             self.g_spin_high.set_value(self.m_highest_value)
 
-def _test():
-    w = gtk.Window(gtk.WINDOW_TOPLEVEL)
-    vbox = gtk.VBox()
-    w.add(vbox)
-    #####
-    ns  = NotenameSpinButton("cis''")
-    ns.show()
-    vbox.pack_start(ns, False)
-    #####
-    adj = gtk.Adjustment(mpd.notename_to_int('c'), 1.0, 127.0, 1.0, 12.0, 0.0)
-    n = NotenameSpinButton("d'")
-    vbox.pack_start(n)
-
-    hbox = gtk.HBox()
-    vbox.pack_start(hbox)
-    s1 = NotenameSpinButton("c")
-    s2 = NotenameSpinButton("c'")
-    hbox.pack_start(s1)
-    hbox.pack_start(s2)
-    con = NotenameRangeController(s1, s2, "c,", "c''")
-
-    l = gtk.Entry()
-    l.set_text("test<sup>3</sup>")
-    vbox.pack_start(l)
-    w.show_all()
-    w.connect('delete_event', gtk.main_quit)
-    gtk.main()
-if __name__ == '__main__':
-    sys.path.append(".")
-    _test()
