@@ -5,9 +5,8 @@ import signal
 
 class ExecutableDoesNotExist(Exception):
     def __init__(self, v):
-        self.v = v
-    def __str__(self):
-        return _("The executable '%s' does not exist. Please check your setup.") % self.v
+        Exception.__init__(self, 
+          _("The executable '%s' does not exist. Please check your setup.") % v)
 
 
 __all__ = ['run_external_program', 'ExecutableDoesNotExist']
