@@ -12,10 +12,10 @@
 This script was used to get white background on the pixmaps.
 """
 
-import os, string
+import os
 for fn in os.listdir("feta"):
 	s = open(os.path.join("feta", fn), "r").read()
-	s = string.replace(s, "\"a c #FFF\"", "\"a c #FF\"")
+	s = s.replace("\"a c #FFF\"", "\"a c #FF\"")
 	f = open(os.path.join("feta", fn), "w")
 	f.write(s)
 	f.close()
