@@ -16,7 +16,8 @@ def do_file(filename):
             years ="%s, 2007" % years
         return r.group('left') + years + r.group('right')
     s2 = r.sub(func, s)
-    if s2 != s:
+    print s2
+    if 0==1:#s2 != s:
         f = file(filename, 'w')
         f.write(s2)
         f.close()
